package binaryRead;

import java.io.FileInputStream;
import java.io.IOException;

/**
 * This class demonstrates how to read raw bytes from a binary file using FileInputStream.
 * It reads one byte at a time from the file and prints out the integer value of each byte.
 *
 * Important Notes:
 * - This example is useful for visualizing what is actually stored in a binary file.
 * - Each byte is printed as a number between 0 and 255 (since Java bytes are 8-bit values).
 * - This does NOT convert the bytes into higher-level types like int, double, or String.
 *   (Use DataInputStream for that — covered later.)
 *
 * How to use:
 * - First run a program that writes binary data (like BinaryDataWriterExample).
 * - Then run this to read and inspect the byte-level contents.
 */
public class FileInputStreamExample {

    public static void main(String[] args) {
        FileInputStream fis = null;

        try {
            // Open the file "data.bin" for reading raw bytes
            fis = new FileInputStream("data.bin");

            int byteValue;
            int byteCount = 0;

            // Read and print each byte until the end of the file (-1 means EOF)
            while ((byteValue = fis.read()) != -1) {
                System.out.printf("Byte %2d: %3d\n", byteCount, byteValue);
                byteCount++;
            }

            System.out.println("Finished reading " + byteCount + " bytes.");

        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                if (fis != null) {
                    fis.close(); // Always close the stream
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }
}
