package binaryWrite;

import java.io.DataOutputStream;
import java.io.BufferedOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;

/**
 * This class demonstrates how to use DataOutputStream to write Java primitive values
 * to a binary file. The stream is buffered using BufferedOutputStream for efficiency.
 *
 * Important Notes:
 * - The data written is in a binary format, NOT human-readable text.
 * - If you open the resulting file (data.bin) in a text editor, it will look like
 *   garbage or may even appear partially or completely empty.
 * - This is because text editors try to interpret the bytes as printable characters
 *   (e.g., ASCII or UTF-8), but the file contains raw byte representations of Java
 *   primitives, not readable characters.
 */
public class BinaryDataWriterExample {

    public static void main(String[] args) {
        try {
            // Create a FileOutputStream to write to a file named "data.bin"
            FileOutputStream fos = new FileOutputStream("data.bin");  //change to .txt to see in text editor 

            // Wrap the FileOutputStream with a BufferedOutputStream for better performance
            BufferedOutputStream bos = new BufferedOutputStream(fos);

            // Wrap the BufferedOutputStream with a DataOutputStream
            DataOutputStream dos = new DataOutputStream(bos);

            // Write various Java primitive types to the file
            dos.writeInt(12345);        // 4 bytes: raw binary form of an int
            dos.writeDouble(3.14159);   // 8 bytes: IEEE 754 binary representation of a double
            dos.writeBoolean(true);     // 1 byte: 1 = true, 0 = false
            dos.writeUTF("Hello");      // Writes string in modified UTF-8 format with length prefix

            // Always flush or close the stream to ensure data is written to disk
            dos.flush(); // flushes any remaining bytes from buffer to file
            dos.close(); // also flushes and then closes all wrapped streams

            System.out.println("Data written to data.bin successfully.");

        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}

