package binaryWrite;

import java.io.FileOutputStream;
import java.io.IOException;

/**
 * This program writes a sequence of bytes to a file using FileOutputStream.
 * However, the bytes correspond to ASCII characters ('A' to 'E'), so when 
 * the file is opened in a text editor, it displays "ABCDE" instead of 
 * unreadable binary data.
 */
public class BinaryFileWriter {
    public static void main(String[] args) {
        String filename = "output.dat"; // Binary file to write to
        
        try (FileOutputStream fos = new FileOutputStream(filename)) {
            /**
             * This byte array contains the ASCII values for 'A' to 'E'.
             * - 65 -> 'A'
             * - 66 -> 'B'
             * - 67 -> 'C'
             * - 68 -> 'D'
             * - 69 -> 'E'
             * Since these are valid printable ASCII characters, 
             * a text editor will display "ABCDE" when opening the file.
             */
            byte[] data = {65, 66, 67, 68, 69}; 
            
            // Writing the byte array to the file
            fos.write(data);
            
            System.out.println("Data successfully written to " + filename);
        } catch (IOException e) {
            System.err.println("Error writing to file: " + e.getMessage());
        }
    }
}


