package binaryWrite;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Random;

/**
 * This program writes raw binary data to a file using FileOutputStream.
 * Unlike the previous example, it does NOT write readable ASCII values.
 * Instead, it writes random bytes (0-255), many of which are not 
 * printable characters. 
 * 
 * When opened in a text editor, the file will display garbage characters, 
 * symbols, or unrecognized text because text editors expect readable 
 * ASCII or UTF-8 characters.
 */
public class BinaryFileWriter1 {
    public static void main(String[] args) {
        String filename = "output.dat"; // Binary file to write to
        
        try (FileOutputStream fos = new FileOutputStream(filename)) {
            byte[] data = new byte[10]; // Array to hold binary data
            
            /**
             * Filling the array with random binary values (0-255).
             * These are raw binary values that do NOT necessarily 
             * correspond to printable ASCII characters.
             * 
             * When a text editor opens this file, it will fail to 
             * interpret the bytes correctly, displaying garbage text 
             * or symbols instead.
             */
            Random random = new Random();
            random.nextBytes(data);

            // Writing binary data to the file
            fos.write(data);
            
            System.out.println("Binary data successfully written to " + filename);
        } catch (IOException e) {
            System.err.println("Error writing to file: " + e.getMessage());
        }
    }
}

