package standard;

import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.util.Scanner;

/**
 * This example shows how to redirect System.out and System.err to files.
 *
 * - System.out will write to "output.txt"
 * - System.err will write to "error.txt"
 *
 * This is useful when running inside Eclipse or an IDE, where shell redirection isn't used.
 * The program still reads input from System.in (keyboard).
 *
 * After running the program, check the project folder for output.txt and error.txt files.
 */
public class RedirectStandardStreams {

    public static void main(String[] args) {
        try {
            // Redirect System.out to output.txt
            PrintStream output = new PrintStream("output.txt");
            System.setOut(output);

            // Redirect System.err to error.txt
            PrintStream error = new PrintStream("error.txt");
            System.setErr(error);

            // Still use System.in (Eclipse console or terminal)
            Scanner scanner = new Scanner(System.in);

            System.out.println("Enter an integer:");

            if (scanner.hasNextInt()) {
                int value = scanner.nextInt();
                System.out.println("You entered: " + value);

                if (value < 0) {
                    System.err.println("Warning: Negative number entered.");
                }
            } else {
                System.err.println("Error: Not a valid integer.");
            }

            scanner.close();

        } catch (FileNotFoundException e) {
            // If the files can't be opened, print to the original console
            e.printStackTrace();
        }
    }
}

