package standard;

import java.util.Scanner;

/**
 * This example demonstrates Java's standard I/O streams:
 *
 * 1. System.in  → Standard input stream (usually the keyboard).
 * 2. System.out → Standard output stream (the console).
 * 3. System.err → Standard error stream (also the console by default, but used for error messages).
 *
 * These streams are part of the System class in the java.lang package and are always available.
 *
 * Key Uses:
 * - System.in allows user input (usually through a Scanner).
 * - System.out is used for normal program output.
 * - System.err is used for error messages and debugging (can be redirected separately).
 */
public class StandardIOExample {

    public static void main(String[] args) {

        // Create a Scanner to read from System.in (keyboard input)
        Scanner scanner = new Scanner(System.in);

        // Prompt the user
        System.out.println("Enter a number:");

        // Try to read an integer from the user
        if (scanner.hasNextInt()) {
            int value = scanner.nextInt();

            // Normal output: goes to System.out
            System.out.println("You entered: " + value);

            // A warning message to show System.err (for demonstration)
            if (value < 0) {
                System.err.println("Warning: You entered a negative number.");
            }

        } else {
            // Error message: use System.err to report bad input
            System.err.println("Error: That is not a valid integer.");
        }

        scanner.close();
    }
}

